schema

package
v0.0.0-...-a14b142 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 8, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CoreCert

type CoreCert struct {
	ent.Schema
}

CoreCert holds the schema definition for the TLS Certificate entity.

func (CoreCert) Annotations

func (CoreCert) Annotations() []schema.Annotation

func (CoreCert) Edges

func (CoreCert) Edges() []ent.Edge

Edges of the CoreCert.

func (CoreCert) Fields

func (CoreCert) Fields() []ent.Field

Fields of the CoreCert.

func (CoreCert) Indexes

func (CoreCert) Indexes() []ent.Index

func (CoreCert) Mixin

func (CoreCert) Mixin() []ent.Mixin

type CoreDataRelationship

type CoreDataRelationship struct {
	ent.Schema
}

CoreDataRelationship holds the schema definition for the CoreDataRelationship entity.

func (CoreDataRelationship) Annotations

func (CoreDataRelationship) Annotations() []schema.Annotation

func (CoreDataRelationship) Edges

func (CoreDataRelationship) Edges() []ent.Edge

Edges of the CoreDataRelationship.

func (CoreDataRelationship) Fields

func (CoreDataRelationship) Fields() []ent.Field

Fields of the CoreDataRelationship.

func (CoreDataRelationship) Indexes

func (CoreDataRelationship) Indexes() []ent.Index

func (CoreDataRelationship) Mixin

func (CoreDataRelationship) Mixin() []ent.Mixin

type CoreGatewayCluster

type CoreGatewayCluster struct {
	ent.Schema
}

CoreGatewayCluster holds the schema definition for the CoreGatewayCluster entity.

func (CoreGatewayCluster) Annotations

func (CoreGatewayCluster) Annotations() []schema.Annotation

func (CoreGatewayCluster) Edges

func (CoreGatewayCluster) Edges() []ent.Edge

Edges of the CoreGatewayCluster.

func (CoreGatewayCluster) Fields

func (CoreGatewayCluster) Fields() []ent.Field

Fields of the CoreGatewayCluster.

func (CoreGatewayCluster) Indexes

func (CoreGatewayCluster) Indexes() []ent.Index

func (CoreGatewayCluster) Mixin

func (CoreGatewayCluster) Mixin() []ent.Mixin

type CoreGatewayHttpRoute

type CoreGatewayHttpRoute struct {
	ent.Schema
}

CoreGatewayHttpRoute holds the schema definition for the HTTP Route entity.

func (CoreGatewayHttpRoute) Annotations

func (CoreGatewayHttpRoute) Annotations() []schema.Annotation

func (CoreGatewayHttpRoute) Edges

func (CoreGatewayHttpRoute) Edges() []ent.Edge

Edges of the CoreGatewayHttpRoute.

func (CoreGatewayHttpRoute) Fields

func (CoreGatewayHttpRoute) Fields() []ent.Field

Fields of the CoreGatewayHttpRoute.

func (CoreGatewayHttpRoute) Indexes

func (CoreGatewayHttpRoute) Indexes() []ent.Index

func (CoreGatewayHttpRoute) Mixin

func (CoreGatewayHttpRoute) Mixin() []ent.Mixin

type CoreGatewayL4Listener

type CoreGatewayL4Listener struct {
	ent.Schema
}

CoreGatewayL4Listener holds the schema definition for the TCP/UDP Listener entity.

func (CoreGatewayL4Listener) Annotations

func (CoreGatewayL4Listener) Annotations() []schema.Annotation

func (CoreGatewayL4Listener) Edges

func (CoreGatewayL4Listener) Edges() []ent.Edge

Edges of the CoreGatewayL4Listener.

func (CoreGatewayL4Listener) Fields

func (CoreGatewayL4Listener) Fields() []ent.Field

Fields of the CoreGatewayL4Listener.

func (CoreGatewayL4Listener) Indexes

func (CoreGatewayL4Listener) Indexes() []ent.Index

func (CoreGatewayL4Listener) Mixin

func (CoreGatewayL4Listener) Mixin() []ent.Mixin

type CoreGatewayL7Listener

type CoreGatewayL7Listener struct {
	ent.Schema
}

CoreGatewayL7Listener holds the schema definition for the HTTP Listener entity.

func (CoreGatewayL7Listener) Annotations

func (CoreGatewayL7Listener) Annotations() []schema.Annotation

func (CoreGatewayL7Listener) Edges

func (CoreGatewayL7Listener) Edges() []ent.Edge

Edges of the CoreGatewayL7Listener.

func (CoreGatewayL7Listener) Fields

func (CoreGatewayL7Listener) Fields() []ent.Field

Fields of the CoreGatewayL7Listener.

func (CoreGatewayL7Listener) Indexes

func (CoreGatewayL7Listener) Indexes() []ent.Index

func (CoreGatewayL7Listener) Mixin

func (CoreGatewayL7Listener) Mixin() []ent.Mixin

type CoreGatewayNode

type CoreGatewayNode struct {
	ent.Schema
}

CoreGatewayNode holds the schema definition for the CoreGatewayNode entity.

func (CoreGatewayNode) Annotations

func (CoreGatewayNode) Annotations() []schema.Annotation

func (CoreGatewayNode) Edges

func (CoreGatewayNode) Edges() []ent.Edge

Edges of the CoreGatewayNode.

func (CoreGatewayNode) Fields

func (CoreGatewayNode) Fields() []ent.Field

Fields of the CoreGatewayNode.

func (CoreGatewayNode) Indexes

func (CoreGatewayNode) Indexes() []ent.Index

func (CoreGatewayNode) Mixin

func (CoreGatewayNode) Mixin() []ent.Mixin

type CoreMenu

type CoreMenu struct {
	ent.Schema
}

CoreMenu holds the schema definition for the CoreMenu entity.

func (CoreMenu) Annotations

func (CoreMenu) Annotations() []schema.Annotation

func (CoreMenu) Edges

func (CoreMenu) Edges() []ent.Edge

Edges of the CoreMenu.

func (CoreMenu) Fields

func (CoreMenu) Fields() []ent.Field

Fields of the CoreMenu.

func (CoreMenu) Indexes

func (CoreMenu) Indexes() []ent.Index

func (CoreMenu) Mixin

func (CoreMenu) Mixin() []ent.Mixin

type CoreOnLineUser

type CoreOnLineUser struct {
	ent.Schema
}

CoreOnLineUser holds the schema definition for the CoreOnLineUser entity.

func (CoreOnLineUser) Annotations

func (CoreOnLineUser) Annotations() []schema.Annotation

func (CoreOnLineUser) Edges

func (CoreOnLineUser) Edges() []ent.Edge

Edges of the CoreOnLineUser.

func (CoreOnLineUser) Fields

func (CoreOnLineUser) Fields() []ent.Field

Fields of the CoreOnLineUser.

func (CoreOnLineUser) Indexes

func (CoreOnLineUser) Indexes() []ent.Index

func (CoreOnLineUser) Mixin

func (CoreOnLineUser) Mixin() []ent.Mixin

type CoreOperationLog

type CoreOperationLog struct {
	ent.Schema
}

CoreOperationLog holds the schema definition for the CoreOperationLog entity.

func (CoreOperationLog) Annotations

func (CoreOperationLog) Annotations() []schema.Annotation

func (CoreOperationLog) Edges

func (CoreOperationLog) Edges() []ent.Edge

Edges of the CoreOperationLog.

func (CoreOperationLog) Fields

func (CoreOperationLog) Fields() []ent.Field

Fields of the CoreOperationLog.

func (CoreOperationLog) Indexes

func (CoreOperationLog) Indexes() []ent.Index

func (CoreOperationLog) Mixin

func (CoreOperationLog) Mixin() []ent.Mixin

type CoreRole

type CoreRole struct {
	ent.Schema
}

CoreRole holds the schema definition for the CoreRole entity.

func (CoreRole) Annotations

func (CoreRole) Annotations() []schema.Annotation

func (CoreRole) Edges

func (CoreRole) Edges() []ent.Edge

Edges of the CoreRole. 角色与用户一对多关系

func (CoreRole) Fields

func (CoreRole) Fields() []ent.Field

Fields of the CoreRole.

func (CoreRole) Indexes

func (CoreRole) Indexes() []ent.Index

func (CoreRole) Mixin

func (CoreRole) Mixin() []ent.Mixin

type CoreUpstream

type CoreUpstream struct {
	ent.Schema
}

CoreUpstream holds the schema definition for the Upstream entity.

func (CoreUpstream) Annotations

func (CoreUpstream) Annotations() []schema.Annotation

func (CoreUpstream) Edges

func (CoreUpstream) Edges() []ent.Edge

Edges of the CoreUpstream.

func (CoreUpstream) Fields

func (CoreUpstream) Fields() []ent.Field

Fields of the CoreUpstream.

func (CoreUpstream) Indexes

func (CoreUpstream) Indexes() []ent.Index

func (CoreUpstream) Mixin

func (CoreUpstream) Mixin() []ent.Mixin

type CoreUpstreamHost

type CoreUpstreamHost struct {
	ent.Schema
}

CoreUpstreamHost holds the schema definition for the Upstream Host entity.

func (CoreUpstreamHost) Annotations

func (CoreUpstreamHost) Annotations() []schema.Annotation

func (CoreUpstreamHost) Edges

func (CoreUpstreamHost) Edges() []ent.Edge

Edges of the CoreUpstreamHost.

func (CoreUpstreamHost) Fields

func (CoreUpstreamHost) Fields() []ent.Field

Fields of the CoreUpstreamHost.

func (CoreUpstreamHost) Indexes

func (CoreUpstreamHost) Indexes() []ent.Index

func (CoreUpstreamHost) Mixin

func (CoreUpstreamHost) Mixin() []ent.Mixin

type CoreUser

type CoreUser struct {
	ent.Schema
}

CoreUser holds the schema definition for the CoreUser entity.

func (CoreUser) Annotations

func (CoreUser) Annotations() []schema.Annotation

func (CoreUser) Edges

func (CoreUser) Edges() []ent.Edge

Edges of the CoreUser. 用户与角色多对一关系

func (CoreUser) Fields

func (CoreUser) Fields() []ent.Field

Fields of the CoreUser.

func (CoreUser) Indexes

func (CoreUser) Indexes() []ent.Index

func (CoreUser) Mixin

func (CoreUser) Mixin() []ent.Mixin

Jump to