Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CoreCert ¶
CoreCert holds the schema definition for the TLS Certificate entity.
func (CoreCert) Annotations ¶
func (CoreCert) Annotations() []schema.Annotation
type CoreDataRelationship ¶
CoreDataRelationship holds the schema definition for the CoreDataRelationship entity.
func (CoreDataRelationship) Annotations ¶
func (CoreDataRelationship) Annotations() []schema.Annotation
func (CoreDataRelationship) Edges ¶
func (CoreDataRelationship) Edges() []ent.Edge
Edges of the CoreDataRelationship.
func (CoreDataRelationship) Fields ¶
func (CoreDataRelationship) Fields() []ent.Field
Fields of the CoreDataRelationship.
func (CoreDataRelationship) Indexes ¶
func (CoreDataRelationship) Indexes() []ent.Index
func (CoreDataRelationship) Mixin ¶
func (CoreDataRelationship) Mixin() []ent.Mixin
type CoreGatewayCluster ¶
CoreGatewayCluster holds the schema definition for the CoreGatewayCluster entity.
func (CoreGatewayCluster) Annotations ¶
func (CoreGatewayCluster) Annotations() []schema.Annotation
func (CoreGatewayCluster) Edges ¶
func (CoreGatewayCluster) Edges() []ent.Edge
Edges of the CoreGatewayCluster.
func (CoreGatewayCluster) Fields ¶
func (CoreGatewayCluster) Fields() []ent.Field
Fields of the CoreGatewayCluster.
func (CoreGatewayCluster) Indexes ¶
func (CoreGatewayCluster) Indexes() []ent.Index
func (CoreGatewayCluster) Mixin ¶
func (CoreGatewayCluster) Mixin() []ent.Mixin
type CoreGatewayHttpRoute ¶
CoreGatewayHttpRoute holds the schema definition for the HTTP Route entity.
func (CoreGatewayHttpRoute) Annotations ¶
func (CoreGatewayHttpRoute) Annotations() []schema.Annotation
func (CoreGatewayHttpRoute) Edges ¶
func (CoreGatewayHttpRoute) Edges() []ent.Edge
Edges of the CoreGatewayHttpRoute.
func (CoreGatewayHttpRoute) Fields ¶
func (CoreGatewayHttpRoute) Fields() []ent.Field
Fields of the CoreGatewayHttpRoute.
func (CoreGatewayHttpRoute) Indexes ¶
func (CoreGatewayHttpRoute) Indexes() []ent.Index
func (CoreGatewayHttpRoute) Mixin ¶
func (CoreGatewayHttpRoute) Mixin() []ent.Mixin
type CoreGatewayL4Listener ¶
CoreGatewayL4Listener holds the schema definition for the TCP/UDP Listener entity.
func (CoreGatewayL4Listener) Annotations ¶
func (CoreGatewayL4Listener) Annotations() []schema.Annotation
func (CoreGatewayL4Listener) Edges ¶
func (CoreGatewayL4Listener) Edges() []ent.Edge
Edges of the CoreGatewayL4Listener.
func (CoreGatewayL4Listener) Fields ¶
func (CoreGatewayL4Listener) Fields() []ent.Field
Fields of the CoreGatewayL4Listener.
func (CoreGatewayL4Listener) Indexes ¶
func (CoreGatewayL4Listener) Indexes() []ent.Index
func (CoreGatewayL4Listener) Mixin ¶
func (CoreGatewayL4Listener) Mixin() []ent.Mixin
type CoreGatewayL7Listener ¶
CoreGatewayL7Listener holds the schema definition for the HTTP Listener entity.
func (CoreGatewayL7Listener) Annotations ¶
func (CoreGatewayL7Listener) Annotations() []schema.Annotation
func (CoreGatewayL7Listener) Edges ¶
func (CoreGatewayL7Listener) Edges() []ent.Edge
Edges of the CoreGatewayL7Listener.
func (CoreGatewayL7Listener) Fields ¶
func (CoreGatewayL7Listener) Fields() []ent.Field
Fields of the CoreGatewayL7Listener.
func (CoreGatewayL7Listener) Indexes ¶
func (CoreGatewayL7Listener) Indexes() []ent.Index
func (CoreGatewayL7Listener) Mixin ¶
func (CoreGatewayL7Listener) Mixin() []ent.Mixin
type CoreGatewayNode ¶
CoreGatewayNode holds the schema definition for the CoreGatewayNode entity.
func (CoreGatewayNode) Annotations ¶
func (CoreGatewayNode) Annotations() []schema.Annotation
func (CoreGatewayNode) Edges ¶
func (CoreGatewayNode) Edges() []ent.Edge
Edges of the CoreGatewayNode.
func (CoreGatewayNode) Fields ¶
func (CoreGatewayNode) Fields() []ent.Field
Fields of the CoreGatewayNode.
func (CoreGatewayNode) Indexes ¶
func (CoreGatewayNode) Indexes() []ent.Index
func (CoreGatewayNode) Mixin ¶
func (CoreGatewayNode) Mixin() []ent.Mixin
type CoreMenu ¶
CoreMenu holds the schema definition for the CoreMenu entity.
func (CoreMenu) Annotations ¶
func (CoreMenu) Annotations() []schema.Annotation
type CoreOnLineUser ¶
CoreOnLineUser holds the schema definition for the CoreOnLineUser entity.
func (CoreOnLineUser) Annotations ¶
func (CoreOnLineUser) Annotations() []schema.Annotation
func (CoreOnLineUser) Fields ¶
func (CoreOnLineUser) Fields() []ent.Field
Fields of the CoreOnLineUser.
func (CoreOnLineUser) Indexes ¶
func (CoreOnLineUser) Indexes() []ent.Index
func (CoreOnLineUser) Mixin ¶
func (CoreOnLineUser) Mixin() []ent.Mixin
type CoreOperationLog ¶
CoreOperationLog holds the schema definition for the CoreOperationLog entity.
func (CoreOperationLog) Annotations ¶
func (CoreOperationLog) Annotations() []schema.Annotation
func (CoreOperationLog) Edges ¶
func (CoreOperationLog) Edges() []ent.Edge
Edges of the CoreOperationLog.
func (CoreOperationLog) Fields ¶
func (CoreOperationLog) Fields() []ent.Field
Fields of the CoreOperationLog.
func (CoreOperationLog) Indexes ¶
func (CoreOperationLog) Indexes() []ent.Index
func (CoreOperationLog) Mixin ¶
func (CoreOperationLog) Mixin() []ent.Mixin
type CoreRole ¶
CoreRole holds the schema definition for the CoreRole entity.
func (CoreRole) Annotations ¶
func (CoreRole) Annotations() []schema.Annotation
type CoreUpstream ¶
CoreUpstream holds the schema definition for the Upstream entity.
func (CoreUpstream) Annotations ¶
func (CoreUpstream) Annotations() []schema.Annotation
func (CoreUpstream) Indexes ¶
func (CoreUpstream) Indexes() []ent.Index
func (CoreUpstream) Mixin ¶
func (CoreUpstream) Mixin() []ent.Mixin
type CoreUpstreamHost ¶
CoreUpstreamHost holds the schema definition for the Upstream Host entity.
func (CoreUpstreamHost) Annotations ¶
func (CoreUpstreamHost) Annotations() []schema.Annotation
func (CoreUpstreamHost) Edges ¶
func (CoreUpstreamHost) Edges() []ent.Edge
Edges of the CoreUpstreamHost.
func (CoreUpstreamHost) Fields ¶
func (CoreUpstreamHost) Fields() []ent.Field
Fields of the CoreUpstreamHost.
func (CoreUpstreamHost) Indexes ¶
func (CoreUpstreamHost) Indexes() []ent.Index
func (CoreUpstreamHost) Mixin ¶
func (CoreUpstreamHost) Mixin() []ent.Mixin
type CoreUser ¶
CoreUser holds the schema definition for the CoreUser entity.
func (CoreUser) Annotations ¶
func (CoreUser) Annotations() []schema.Annotation